@@ -89,6 +89,9 @@ ttc_get_translation_table (const gchar* language)
     gchar*	fn	= NULL;
     gchar*	dir_fn 	= NULL;
     FILE* 	fp	= NULL;
+
+    if (!strcmp (language, "none"))
+	return NULL;
 	
     /* search the key in the table first */
     value = (guint8*) g_hash_table_lookup (translation_table_cache, language);
@@ -176,6 +179,7 @@ brl_disp_new ()
 	
     brl_disp = g_malloc0(sizeof(BRLDisp));
     brl_disp->dots = g_byte_array_new();
+    brl_disp->text = g_byte_array_new();
     brl_disp->cursor_position = -1;	/* no cursor */
     brl_disp->cursor_style = BRL_CS_UNDERLINE;
     brl_disp->cursor_mask = 0xC0;
@@ -191,6 +195,7 @@ brl_disp_free (BRLDisp *brl_disp)
 {
     g_free (brl_disp->role);
     g_byte_array_free (brl_disp->dots, TRUE);
+    g_byte_array_free (brl_disp->text, TRUE);
     g_free (brl_disp);
 }
 
@@ -213,6 +218,9 @@ brl_disp_copy (BRLDisp *brl_disp)
     /* copy the dots array */
     bd->dots = g_byte_array_new();
     g_byte_array_append (bd->dots, brl_disp->dots->data, brl_disp->dots->len);
+
+    bd->text = g_byte_array_new();
+    g_byte_array_append (bd->text, brl_disp->text->data, brl_disp->text->len);
 	
     return bd;
 }
@@ -323,7 +331,24 @@ brl_disp_add_dots (BRLDisp *brl_disp,
 		   guint8*  dots, 
 		   gint     len)
 {
+    guint8 *text;
+
+     /*	fprintf(stderr, "BRL: add dots: ID %08x, len %d\n", brl_disp, len); */
     g_byte_array_append (brl_disp->dots, dots, len);
+    text = g_alloca(len);
+    memset(text,' ',len);
+    g_byte_array_append (brl_disp->text, text, len);
+}
+
+void brl_disp_add_text (BRLDisp *brl_disp, guint8* text, int len)
+{
+    guint8 *dots;
+
+    /*	fprintf(stderr, "BRL: add text: ID %08x, len %d\n", brl_disp, len); */
+    dots = g_alloca(len);
+    memset(dots,0,len);
+    g_byte_array_append (brl_disp->dots, dots, len);
+    g_byte_array_append (brl_disp->text, text, len);
 }
 
 /* __ BrlOut  METHODS _________________________________________________________ */
@@ -440,6 +465,7 @@ brl_out_to_driver (BRLOut *brl_out)
 	    /* fprintf (stderr, "CP:%d, M:%02X, P:%02X\n", brl_disp->cursor_position, brl_disp->cursor_mask, brl_disp->cursor_pattern); */
 			
 	    if (brl_disp->cursor_position >= 0 &&
+		brl_disp->cursor_position >= 0 &&
 		brl_disp->cursor_position < 1024) /* to avoid ill values eating too much mem ... */
 	    {
 		/* the display has a potentially visible cursor */
@@ -460,7 +486,7 @@ brl_out_to_driver (BRLOut *brl_out)
  	    /* fprintf(stderr, "BRL: set dots: did %d, start %d, len %d, off %d\n",
 			did, brl_disp->Start, brl_disp->Dots->len, brl_disp->Offset); */
 			
-	    brl_set_dots (did, brl_disp->start, &brl_disp->dots->data[0], brl_disp->dots->len, brl_disp->offset, brl_disp->cursor_position);	
+	    brl_set_dots (did, brl_disp->start, &brl_disp->dots->data[0], &brl_disp->text->data[0], brl_disp->dots->len, brl_disp->offset, brl_disp->cursor_position);	
 	}	
     }
 	
@@ -866,7 +892,7 @@ brl_characters (void          *ctx,
     gchar*	tch;
     gchar**	tokens;
     guint8	tdots;
-    guint8*	dotbuff;
+    guint8*	buff;
 		
     tch = g_strndup ((gchar*)ch, len);
     tch = g_strstrip(tch);
@@ -894,7 +920,7 @@ brl_characters (void          *ctx,
 	    str_utf = g_strndup ((const gchar*)ch, len);
 	    str_len = g_utf8_strlen (str_utf, -1);
 	    /* convert text to braille dots */
-	    dotbuff = malloc (str_len);			
+	    buff = malloc (str_len);			
 	    str_crt = str_utf;					
 			
 	    for (i = 0; i < str_len; ++i)
@@ -905,35 +931,40 @@ brl_characters (void          *ctx,
 		    if (TT_SIZE > g_utf8_get_char (str_crt))
 		    {
 			/* use the translation table */
-			dotbuff[i] = tbrl_disp->translation_table[g_utf8_get_char (str_crt)];
+			buff[i] = tbrl_disp->translation_table[g_utf8_get_char (str_crt)];
 		    }
 		    else
 		    {
 			/* use the last simbol from translation table, 
 			when the character code is grant then the 
 			number of simbols in translation table*/
-			dotbuff[i] = tbrl_disp->translation_table[TT_SIZE - 1];
+			buff[i] = tbrl_disp->translation_table[TT_SIZE - 1];
 		    }
+		    /* consider 6/8 dot Braille style */
+		    if (tbrl_out->braille_style == BRL_6_DOTS)
+		    {
+		    	buff[i] &= 0x3F;	/* clear dot 78 */
+		    }
+		    /* merge the Braille attributes				 */
+		    buff[i] |= tbrl_disp->attribute;
 		}
 		else
 		{
-		    /* no table, no dots */
-		    dotbuff[i] = 0;
-		}
-						/* consider 6/8 dot Braille style */
-		if (tbrl_out->braille_style == BRL_6_DOTS)
-		{
-		    dotbuff[i] &= 0x3F;	/* clear dot 78 */
+		    /* no table, no translation, just give low UTF8 */
+		    if (TT_SIZE > g_utf8_get_char (str_crt))
+			buff[i] = g_utf8_get_char (str_crt);
+		    else
+			buff[i] = '?';
 		}
 				
-		/* merge the Braille attributes				 */
-		dotbuff[i] |= tbrl_disp->attribute;
 		str_crt = g_utf8_find_next_char (str_crt, NULL);
 	    }
-							
-	    brl_disp_add_dots (tbrl_disp, dotbuff, str_len );
-			
-	    free (dotbuff);
+	    if (tbrl_disp->translation_table)
+		brl_disp_add_dots (tbrl_disp, buff, str_len );
+	    else
+		brl_disp_add_text (tbrl_disp, buff, str_len );
+	    	    
+	    free (buff);
 	    free (str_utf);	
 	break;
 	}
