@@ -80,6 +80,8 @@ const struct
     {N_("German"),		"de"},
     {N_("Spanish"),		"es"},
     {N_("Swedish"),		"sv"},
+    {N_("French"),		"fr"},
+    {N_("none"),		"none"},
     {NULL,		NULL}
 };
 
@@ -100,7 +102,8 @@ const gchar *status_cell_value [] =
 **/
 /* Window  */
 GtkWidget		*w_braille_settings = NULL;
-
+static GtkWidget	*bt_braille_style;
+static GtkWidget	*bt_cursor_settings;
 
 /**
  * Braille device widgets 					
@@ -290,14 +293,22 @@ brlui_load_braille_settings (GtkWidget *parent_window)
     if (!w_braille_settings)
     {
 	GladeXML *xml;	
+	gboolean sensitivity;
+
 	xml = gn_load_interface ("Braille_Settings/braille_settings.glade2", NULL);
 	sru_return_val_if_fail (xml, FALSE);
 	brlui_set_handlers_braille_settings (xml, braille_setting);
+	bt_braille_style = glade_xml_get_widget(xml, "bt_braille_style_");
+	bt_cursor_settings = glade_xml_get_widget(xml, "bt_cursor_settings");
 	g_object_unref (G_OBJECT (xml));
 	gtk_window_set_transient_for (GTK_WINDOW (w_braille_settings),
 	    			      GTK_WINDOW (parent_window));
 	gtk_window_set_destroy_with_parent ( GTK_WINDOW (w_braille_settings), 
 						TRUE);
+	sensitivity = strcmp (braille_setting->translation_table, "none");
+	gtk_widget_set_sensitive (GTK_WIDGET (bt_braille_style), sensitivity);
+	gtk_widget_set_sensitive (GTK_WIDGET (bt_cursor_settings), sensitivity);
+	
     }
     else
 	gtk_widget_show (w_braille_settings);
@@ -630,6 +641,7 @@ brlui_translation_table_changeing (Braille *braille_setting)
     GtkTreeIter      iter;
     gint 	     l_iter;
     gchar 	    *key;
+    gboolean	    sensitivity;
 
     sru_return_if_fail (braille_setting);
     
@@ -652,6 +664,10 @@ brlui_translation_table_changeing (Braille *braille_setting)
 	    g_free (braille_setting->translation_table);
 	    braille_setting->translation_table = g_strdup (trans_table_list [ l_iter ].file_name);
 	    brlconf_translation_table_set (braille_setting->translation_table);
+
+    	    sensitivity = strcmp (braille_setting->translation_table, "none");
+    	    gtk_widget_set_sensitive (GTK_WIDGET (bt_braille_style), sensitivity);
+    	    gtk_widget_set_sensitive (GTK_WIDGET (bt_cursor_settings), sensitivity);
 	}
     }
     g_free (key);
