@@ -1,7 +1,7 @@
 /* cmdmapui.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -55,10 +55,10 @@ CmdMapFunctionsList cmd_function[] =
 	{"increase cursor size", N_("increase cursor size")},
 	{"invert on/off", 	N_("invert on/off")},
 	{"mag default", 	N_("magnifier default")},
-	{"crosswire on/off", 	N_("crosshair on/off")},
-	{"crosswire clip on/off", N_("crosshair clip on/off")},
-	{"decrease crosswire size", N_("decrease crosshair size")},
-	{"increase crosswire size", N_("increase crosshair size")},
+	{"crosswire on/off", 	N_("crosswire on/off")},
+	{"crosswire clip on/off", N_("crosswire clip on/off")},
+	{"decrease crosswire size", N_("decrease crosswire size")},
+	{"increase crosswire size", N_("increase crosswire size")},
 	{"automatic panning on/off", N_("automatic panning on/off")},
 	{"mouse tracking toggle", N_("mouse tracking toggle")},
 	{"load magnifier defaults", N_("load magnifier defaults")},
@@ -95,7 +95,7 @@ CmdMapFunctionsList cmd_function[] =
 	{"flat review", 	N_("flat review")},
 	{"window hierarchy", 	N_("window hierarchy")},
 	{"read whole window", 	N_("read whole window")},
-	{"detailed informations", N_("detailed informations")},
+	{"detailed informations", N_("detailed information")},
 	{"do default action", 	N_("do default action")},
 	{"window overview", 	N_("window overview")},
 	{"find next",		N_("find next")},
@@ -340,7 +340,7 @@ cmdui_get_text_from_code (const gchar *str)
 				str[POS_DIGIT_3]);
 
     delimit = g_strrstr (str, KEY_NAME_SEPARATOR);
-    (const gchar*)tmp = str;
+    tmp = (gchar *)str;
     if (delimit)
 	tmp = delimit + 1;
 
@@ -390,7 +390,7 @@ cmdui_get_code_from_text (const gchar *str)
     }
     
     delimit = g_strrstr (str, KEY_SEPARATOR);
-    (const gchar*)tmp = str;
+    tmp = (gchar *)str;
     
     if (delimit)
 	tmp = delimit + 1;
@@ -793,7 +793,7 @@ cmdui_get_key (void)
     
     line = alt || shift || ctrl ;
     
-    (const gchar*)key = cmdui_get_key_keystring (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (cb_key_list)->entry)));
+    key = (gchar *)cmdui_get_key_keystring (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (cb_key_list)->entry)));
     
     if (!key || strlen (key) == 0)
 	return rv;
