@@ -285,11 +285,11 @@ sr_config_changed_callback (guint cnxn_id,
     SRstruct->module = srconf_notify_directories[(gint)user_data].module;
     if (strlen (gconf_entry_get_key (entry)) >
 	strlen (gconf_root_dir_path) +
-	strlen (srconf_notify_directories[(guint)user_data].notify_path))
+	strlen (srconf_notify_directories[GPOINTER_TO_UINT(user_data)].notify_path))
     {    
 	SRstruct->key = g_strdup (gconf_entry_get_key (entry) +
 			    	  strlen (gconf_root_dir_path) +
-			          strlen (srconf_notify_directories[(guint)user_data].notify_path) + 1);
+				  strlen (srconf_notify_directories[GPOINTER_TO_UINT(user_data)].notify_path) + 1);
     }
     else
 	SRstruct->key = g_path_get_basename (gconf_entry_get_key(entry));
@@ -392,7 +392,7 @@ srconf_init (SRConfCB srconfcb,
 	     const gchar *_gconf_root_dir_path,
 	     const gchar *config_source)
 {
-    gint i;
+    guint i;
     GError *error = NULL;    
     gchar *path = NULL;
     
@@ -424,7 +424,7 @@ srconf_init (SRConfCB srconfcb,
 	for( i=0; i < NUM_OF_CONFIGURABLES; i++ )
 	{
     	    path = g_strdup_printf ("%s%s", gconf_root_dir_path, srconf_notify_directories[i].notify_path);
-    	    srconf_notify_directories[i].cnx_id = gconf_client_notify_add (gconf_client, path, sr_config_client_changed_callback, (gpointer)(i), NULL, &error);
+    	    srconf_notify_directories[i].cnx_id = gconf_client_notify_add (gconf_client, path, sr_config_client_changed_callback, GUINT_TO_POINTER(i), NULL, &error);
 	
 	    if (error != NULL)
 	    {
@@ -460,7 +460,7 @@ srconf_init (SRConfCB srconfcb,
 	for( i=0; i < NUM_OF_CONFIGURABLES; i++ )
 	{
     	    path = g_strdup_printf ("%s%s", gconf_root_dir_path, srconf_notify_directories[i].notify_path);
-    	    srconf_notify_directories[i].cnx_id = gconf_engine_notify_add (gconf_engine, path, sr_config_engine_changed_callback, (gpointer)(i),  &error);
+    	    srconf_notify_directories[i].cnx_id = gconf_engine_notify_add (gconf_engine, path, sr_config_engine_changed_callback, GUINT_TO_POINTER(i),  &error);
 	
 	    if (error != NULL)
 	    {
