@@ -1746,15 +1746,7 @@ src_speech_translate_symbol (gint index)
 
     if (src_speech_dictionary[index].translate)
     {
-	if (src_speech_dictionary[index].character == '.' ||
-	    src_speech_dictionary[index].character == '!' ||
-	    src_speech_dictionary[index].character == '?')
-	{
-	    rv = g_strconcat ("  ", _(src_speech_dictionary[index].singular), " ", NULL);
-	    rv[0] = src_speech_dictionary[index].character;
-	}
-	else
-	    rv = g_strconcat (" ", _(src_speech_dictionary[index].singular), " ", NULL);
+	rv = g_strconcat (" ", _(src_speech_dictionary[index].singular), " ", NULL);
     }
     else
     {
